==> openrqm-1.0.2.tar.gz: lib/api/document_api.dart <==
part of openrqm.api;



class DocumentApi {
  final ApiClient apiClient;

  DocumentApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get a document
  ///
  /// 
  Future<RQMDocument> getDocument() async {
    Object postBody = null;

    // verify required params are set

    // create path and map variables
    String path = "/document".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'RQMDocument') as RQMDocument ;
    } else {
      return null;
    }
  }
}

==> openrqm-1.0.3.tar.gz: lib/api/document_api.dart <==
part of openrqm.api;



class DocumentApi {
  final ApiClient apiClient;

  DocumentApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get a document with HTTP info returned
  ///
  /// 
  Future<Response> getDocumentWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/document".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get a document
  ///
  /// 
  Future<RQMDocument> getDocument() async {
    Response response = await getDocumentWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'RQMDocument') as RQMDocument;
    } else {
      return null;
    }
  }

}
